// Wire Slave Receiver
// by Nicholas Zambetti <http://www.zambetti.com>

// Demonstrates use of the Wire library
// Receives data as an I2C/TWI slave device
// Refer to the "Wire Master Writer" example for use with this

// Created 29 March 2006

// This example code is in the public domain.

#include <Wire.h>

extern uint8_t slaveAdr;

int dat;
char buf[64];
uint8_t btn1;
uint8_t btn2;
uint8_t btn3;
uint8_t btn4;
void setup() {
  btn1 = 0;
  btn2 = 0;
  btn3 = 0;
  Wire.begin(0x50);
  TWAMR = B11111111;
  Wire.onReceive(receiveEvent); // register event
  Wire.onRequest(requestEvent) ;
  Serial.begin(115200);           // start serial for output
  Serial.println("start");
}

void loop() {
  if (Serial.available() > 0) {
    switch (Serial.read()) {
      case '1':
        btn1 = 0x80;
        break;
      case '2':
        btn1 = 0x40;
        break;
      case '3':
        btn1 = 0x20;
        break;
      case '4':
        btn1 = 0x10;
        break;
      case '5':
        btn1 = 0x08;
        break;
      case '6':
        btn1 = 0x04;
        break;
      case '7':
        btn1 = 0x02;
        break;
      case '8':
        btn1 = 0x01;
        break;
      case '9':
        btn1 = 0;
        break;
      case 'q':
        btn2 = 0x80;
        break;
      case 'w':
        btn2 = 0x40;
        break;
      case 'e':
        btn2 = 0x20;
        break;
      case 'r':
        btn2 = 0x10;
        break;
      case 't':
        btn2 = 0x08;
        break;
      case 'y':
        btn2 = 0x04;
        break;
      case 'u':
        btn2 = 0x02;
        break;
      case 'i':
        btn2 = 0x01;
        break;
      case 'o':
        btn2 = 0;
        break;
      case 'a':
        btn3 = 0x80;
        break;
      case 's':
        btn3 = 0x40;
        break;
      case 'd':
        btn3 = 0x20;
        break;
      case 'f':
        btn3 = 0x10;
        break;
      case 'g':
        btn3 = 0x08;
        break;
      case 'h':
        btn3 = 0x04;
        break;
      case 'j':
        btn3 = 0x02;
        break;
      case 'k':
        btn3 = 0x01;
        break;
      case 'l':
        btn3 = 0;
        break;
      case 'z':
        btn4 = 0x80;
        break;
      case 'x':
        btn4 = 0x40;
        break;
      case 'c':
        btn4 = 0x20;
        break;
      case 'v':
        btn4 = 0x10;
        break;
      case 'b':
        btn4 = 0x08;
        break;
      case 'n':
        btn4 = 0x04;
        break;
      case 'm':
        btn4 = 0x02;
        break;
      case ',':
        btn4 = 0x01;
        break;
      case '.':
        btn4 = 0;
        break;

    }
    Serial.print("read:");
    Serial.print(btn1, HEX);
    Serial.print(",");
    Serial.print(btn2, HEX);
    Serial.print(",");
    Serial.println(btn3, HEX);
  }
}
// function that executes whenever data is received from master
// this function is registered as an event, see setup()
void receiveEvent(int howMany) {
  dat = Wire.read();    // receive byte as an integer
  Serial.print(slaveAdr, HEX);
  Serial.print(":");
  Serial.println(dat, HEX);
}

void requestEvent() {
  if (slaveAdr == 0x50) {
    switch (dat) {
      case 0:
        Wire.write("\x04\x00\x00\x00", 4);
        break;
      case 4:
        Wire.write("\x01\x00\x00\x12\xef\xcd\xAB\x0B\x0C\x0D\x0E\x0F\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1A\x1B\x1C\x1D\x1E\x1F\x20\x21\x22\x23\x24\x25\x26\x27\x28\x29\x2A\x2B", 40);
        break;
      case 0x40:
        Wire.write("\x00", 1);
        break;
      case 0xa0:
        Wire.write("\x01", 1);
        break;
      case 0xa1:
        Wire.write("\x00\x00", 2);
        break;
      case 0xa3:
        Wire.write("\x02", 1);
        break;
      case 0xa4:
        Wire.write("\x30\x20", 2);
        break;
      case 0xa6:
        Wire.write("\x03", 1);
        break;
      case 0xa7:
        Wire.write("\x30\x1D", 2);
        break;
      case 0xa9:
        Wire.write("\x09", 1);
        break;
      case 0xaa:
        Wire.write("\x02", 1);
        break;
      case 0xab:
        Wire.write("\x0a", 1);
        break;
      case 0xac:
        Wire.write("\x30\x1F", 2);
        break;
      case 0xae:
        Wire.write("\x0b", 1);
        break;
      case 0xaf:
        Wire.write("\x30\x18", 2);
        break;
      case 0xb1:
        Wire.write("\x10", 1);
        break;
      case 0xb2:
        Wire.write("\x30\x1c", 2);
        break;
      case 0xb4:
        Wire.write("\x00", 1);
        break;
    }
  } else if (slaveAdr == 0x30) {
    switch (dat) {
      case 0x20:
        Wire.write(btn1);   // ←:↓:→:↑:opt:R3:L3:share
        break;
      case 0x1D:
        Wire.write(btn2);  // □:×:○:△:R1:L1:R2:L2
        break;
      case 0x1F:
        Wire.write(btn3);  //L2 analog
        break;
      case 0x18:
        Wire.write(btn4);     //R2 analog
        break;
      case 0x1C:
        Wire.write(0);     //report (29)
        break;
    }
  }
}
